@@ -4,7 +4,7 @@ formatting functions in this library.
 
 @
 import Colog.Monad (usingLoggerT)
-import Colog.Simple (Severity (..), colorSevFmt, logger, logNotice, logTextStdout)
+import Colog.Simple (Severity (..), (%), logger, logNotice, logTextStdout, msg, sevc)
 
 usingLoggerT (logger (sevc % msg) logTextStdout Debug) $ logNotice "Take note of this!"
 @
